@@ -48,8 +48,8 @@ class ModelLoader(Generic[GenericDbType]):
             raise InconsistencyError(message=f"{model.__name__} not found")  # type: ignore
         return entity
 
-    @staticmethod
-    async def create(model: GenericDbType, protection: AccessProtectIdentity, dto: PdModel,
+    @classmethod
+    async def create(cls, model: GenericDbType, protection: AccessProtectIdentity, dto: PdModel,
                      **kwargs) -> GenericDbType:
         entity_kwargs = {}
         m2m_fields = {}
@@ -82,19 +82,19 @@ class ModelLoader(Generic[GenericDbType]):
             await getattr(entity, m2m_field).add(*m2m_entities)
         return entity
 
-    @staticmethod
-    async def read(model: GenericDbType, entity_id: EntityId, protection: AccessProtectIdentity,
+    @classmethod
+    async def read(cls, model: GenericDbType, entity_id: EntityId, protection: AccessProtectIdentity,
                    fetch_fields: List[str] | None = None,
                    **kwargs) -> GenericDbType | None:
         query = model.filter(id=entity_id)
         if kwargs:
             query = query.filter(**kwargs)
-        query = await ModelLoader.fetch_related(model, query, fetch_fields)
+        query = await cls.fetch_related(model, query, fetch_fields)
         entity = await query.first()
         return entity
 
-    @staticmethod
-    async def read_all(model: GenericDbType, protection: AccessProtectIdentity, limit: int = None, offset: int = None,
+    @classmethod
+    async def read_all(cls, model: GenericDbType, protection: AccessProtectIdentity, limit: int = None, offset: int = None,
                        fetch_fields: List[str] = None,
                        **kwargs) -> Tuple[List[GenericDbType], int]:
         query = model.filter()
@@ -107,7 +107,7 @@ class ModelLoader(Generic[GenericDbType]):
             query = query.limit(limit)
         if offset:
             query = query.offset(offset)
-        query = await ModelLoader.fetch_related(model, query, fetch_fields)
+        query = await cls.fetch_related(model, query, fetch_fields)
         try:
             entities = await query
             query._limit = None
@@ -117,13 +117,13 @@ class ModelLoader(Generic[GenericDbType]):
             raise InconsistencyError(message="Incorrect filter")
         return entities, total
 
-    @staticmethod
-    async def update(model: GenericDbType, entity_id: EntityId, protection: AccessProtectIdentity, dto: PdModel,
+    @classmethod
+    async def update(cls, model: GenericDbType, entity_id: EntityId, protection: AccessProtectIdentity, dto: PdModel,
                      **kwargs) -> GenericDbType:
-        entity = await ModelLoader.get_entity(model, entity_id)
+        entity = await cls.get_entity(model, entity_id)
         m2m_fields = {}
         entity_kwargs = {field: value for field, value in dto.dict().items() if value is not None}
-        for field, value in entity_kwargs.items():
+        for field, value in entity_kwargs.copy().items():
             if field.endswith('_id') or field.endswith('_ids'):
                 raw_field = field[:field.find("_id")]
                 if raw_field in model._meta.m2m_fields:
@@ -149,11 +149,11 @@ class ModelLoader(Generic[GenericDbType]):
             await getattr(entity, m2m_field).add(*m2m_entities)
         return entity
 
-    @staticmethod
-    async def delete(model: GenericDbType, entity_id: EntityId, protection: AccessProtectIdentity,
+    @classmethod
+    async def delete(cls, model: GenericDbType, entity_id: EntityId, protection: AccessProtectIdentity,
                      **kwargs) -> GenericDbType:
         assert entity_id is not None
-        entity = await ModelLoader.get_entity(model, entity_id)
+        entity = await cls.get_entity(model, entity_id)
         await entity.delete()
         return entity
 
